about summary refs log tree commit diff
path: root/nixpkgs/pkgs/development/libraries/gnutls/3.6.nix
diff options
context:
space:
mode:
Diffstat (limited to 'nixpkgs/pkgs/development/libraries/gnutls/3.6.nix')
-rw-r--r--nixpkgs/pkgs/development/libraries/gnutls/3.6.nix16
1 files changed, 9 insertions, 7 deletions
diff --git a/nixpkgs/pkgs/development/libraries/gnutls/3.6.nix b/nixpkgs/pkgs/development/libraries/gnutls/3.6.nix
index 7fb1af70a289..513f20fd835a 100644
--- a/nixpkgs/pkgs/development/libraries/gnutls/3.6.nix
+++ b/nixpkgs/pkgs/development/libraries/gnutls/3.6.nix
@@ -1,20 +1,22 @@
 { callPackage, fetchurl, ... } @ args:
 
 callPackage ./generic.nix (args // rec {
-  version = "3.6.2";
+  version = "3.6.6";
 
   src = fetchurl {
     url = "mirror://gnupg/gnutls/v3.6/gnutls-${version}.tar.xz";
-    sha256 = "07wdffklwmxpa9i50sh5nwrc5ajb47skrldm6rzjc0jf4dxxpmdw";
+    sha256 = "19rcfgsfxb01cyz8jxmmgkjqc7y5s97amajzyknk1i1amywcm6mv";
   };
 
   # Skip two tests introduced in 3.5.11.  Probable reasons of failure:
   #  - pkgconfig: building against the result won't work before installing
   #  - trust-store: default trust store path (/etc/ssl/...) is missing in sandbox
   # Change p11-kit test to use pkg-config to find p11-kit
   postPatch = ''
-    sed '2iexit 77' -i tests/pkgconfig.sh
-    sed '/^void doit(void)/,$s/{/{ exit(77);/; t' -i tests/trust-store.c
+    sed '2iexit 77' -i tests/{pkgconfig,fastopen}.sh
+    sed '/^void doit(void)/,/^{/ s/{/{ exit(77);/' -i tests/{trust-store,psk-file}.c
     sed 's:/usr/lib64/pkcs11/ /usr/lib/pkcs11/ /usr/lib/x86_64-linux-gnu/pkcs11/:`pkg-config --variable=p11_module_path p11-kit-1`:' -i tests/p11-kit-trust.sh
   '';
 })
@@ -1,20 +1,22 @@
   };
 
-  # Skip two tests introduced in 3.5.11.  Probable reasons of failure:
-  #  - pkgconfig: building against the result won't work before installing
-  #  - trust-store: default trust store path (/etc/ssl/...) is missing in sandbox
+  # Skip some tests:
+  #  - pkgconfig: building against the result won't work before installing (3.5.11)
+  #  - fastopen: no idea; it broke between 3.6.2 and 3.6.3 (3437fdde6 in particular)
+  #  - trust-store: default trust store path (/etc/ssl/...) is missing in sandbox (3.5.11)
+  #  - psk-file: no idea; it broke between 3.6.3 and 3.6.4
   # Change p11-kit test to use pkg-config to find p11-kit
   postPatch = ''